# Yet Another Password Generator

This is a password generator which aims to generate passwords that are:
 * Readable
 * Pronounceable
 * Secure
 * Long

It uses [zxcvbn](https://github.com/dropbox/zxcvbn) to estimate the complexity of the passwords.

This package is provided under the [GNU Affero General Public License](https://www.gnu.org/licenses/agpl-3.0.en.html).

It is provided free of charge, and if you like it, feel free to buy me a beer.
Or, as I'm not currently disclosing my contact informations, feel free to *Wish that I stumble upon a beer*.
